/*
 * File : phInactive.C
 *
 * Description : This file contains the method definitions
 *	for the phInactive class.
 */

#include "phInactive.h"
#include "phActive.h"
#include "phlayer.h"

/*
 * Function : PhActivateReq 
 *
 * Description : This method handles a PH_ActivateReq
 *	primitive. It transmits the PH_ACTIVATE character
 *	on the xmit FIFO.
 */

phStateMachine *
phInactive::PhActivateReq(int &errorCode)
{
	_ph->SendCommand(PH_ACTIVATE);
	errorCode = codeSuccessful;
	delete this;
	return new phActive(_ph);
}

/*
 * Function : PhActivate
 *
 * Description : This function handles the case when
 *	a PH_ACTIVATE character is received on the recv. FIFO.
 *	It sends a PH_ActivateInd primitive to the data-link
 *	layer.
 */

phStateMachine *
phInactive::PhActivate(int &errorCode)
{
	layer *dl = _ph->GetNPlus1Layer();
	if (dl )
		dl->Command(PH_ActivateInd,errorCode);
	delete this;
	return new phActive(_ph);
}

/*
 * Function : PrintState
 *
 * Description : Prints the state.
 */

void 
phInactive::PrintState() 
{
	TRACE(phSmModule,2,("State Inactive\n"));
}

