/*
 * File : scheduler.h
 *
 * Description : This file contains the class declaration for
 *	the scheduler class.
 */

#ifndef _scheduler_h_
#define _scheduler_h_

class eventHandler;
class eventHandlerList;

/*
 * Class : scheduler
 *
 * Description : This class provides the main event loop for
 *	the system. The scheduler uses the select call to both
 *	check for input on files, and to time out. The file 
 *	descriptor sets and timeout values are set by calling
 *	SetEvent() on the list of event handlers, and CheckEvent
 *	is called on each event handler once the select call
 *	completes. The scheduler also provides functions for
 * 	event handlers to add themselves to the scheduling.
 *
 * Attributes:
 *	_scheduler : A static pointer to the scheduler.
 *	_evSrcList : A list of event handlers.
 */

class scheduler {
 public:
	scheduler();
	~scheduler();

	void 		Run();

	void		AddEventHandler(eventHandler *hdl);
	void		DeleteEventHandler(eventHandler *hdl);

	static		scheduler * GetScheduler()
		{ return _scheduler; }

	int		NumOfEventHandlers();

 private:

	static scheduler * _scheduler;
	eventHandlerList *_eventHandlerList;
};

#endif
